Struct aws_sdk_elastictranscoder::client::Client [−][src]
pub struct Client<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Client for Amazon Elastic Transcoder
Client for invoking operations on Amazon Elastic Transcoder. Each operation on Amazon Elastic Transcoder is a method on this
this struct. .send() MUST be invoked on the generated operations to dispatch the request to the service.
Examples
Constructing a client and invoking an operation
// create a shared configuration. This can be used & shared between multiple service clients.
let shared_config = aws_config::load_from_env().await;
let client = aws_sdk_elastictranscoder::Client::new(&shared_config);
// invoke an operation
/* let rsp = client
.<operationname>().
.<param>("some value")
.send().await; */Constructing a client with custom configuration
use aws_config::RetryConfig;
let shared_config = aws_config::load_from_env().await;
let config = aws_sdk_elastictranscoder::config::Builder::from(&shared_config)
.retry_config(RetryConfig::disabled())
.build();
let client = aws_sdk_elastictranscoder::Client::from_conf(config);Implementations
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
Constructs a fluent builder for the CancelJob operation.
See CancelJob for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateJob operation.
See CreateJob for more information about the
operation and its arguments.
Constructs a fluent builder for the CreatePipeline operation.
See CreatePipeline for more information about the
operation and its arguments.
Constructs a fluent builder for the CreatePreset operation.
See CreatePreset for more information about the
operation and its arguments.
Constructs a fluent builder for the DeletePipeline operation.
See DeletePipeline for more information about the
operation and its arguments.
Constructs a fluent builder for the DeletePreset operation.
See DeletePreset for more information about the
operation and its arguments.
Constructs a fluent builder for the ListJobsByPipeline operation.
See ListJobsByPipeline for more information about the
operation and its arguments.
Constructs a fluent builder for the ListJobsByStatus operation.
See ListJobsByStatus for more information about the
operation and its arguments.
Constructs a fluent builder for the ListPipelines operation.
See ListPipelines for more information about the
operation and its arguments.
Constructs a fluent builder for the ListPresets operation.
See ListPresets for more information about the
operation and its arguments.
Constructs a fluent builder for the ReadJob operation.
See ReadJob for more information about the
operation and its arguments.
Constructs a fluent builder for the ReadPipeline operation.
See ReadPipeline for more information about the
operation and its arguments.
Constructs a fluent builder for the ReadPreset operation.
See ReadPreset for more information about the
operation and its arguments.
Constructs a fluent builder for the TestRole operation.
See TestRole for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdatePipeline operation.
See UpdatePipeline for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdatePipelineNotifications operation.
See UpdatePipelineNotifications for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdatePipelineStatus operation.
See UpdatePipelineStatus for more information about the
operation and its arguments.
Creates a client with the given service config and connector override.