#[non_exhaustive]pub struct TestRoleInput {
pub role: Option<String>,
pub input_bucket: Option<String>,
pub output_bucket: Option<String>,
pub topics: Option<Vec<String>>,
}Expand description
The TestRoleRequest structure.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.role: Option<String>The IAM Amazon Resource Name (ARN) for the role that you want Elastic Transcoder to test.
input_bucket: Option<String>The Amazon S3 bucket that contains media files to be transcoded. The action attempts to read from this bucket.
output_bucket: Option<String>The Amazon S3 bucket that Elastic Transcoder writes transcoded media files to. The action attempts to read from this bucket.
topics: Option<Vec<String>>The ARNs of one or more Amazon Simple Notification Service (Amazon SNS) topics that you want the action to send a test notification to.
Implementations
Sourceimpl TestRoleInput
impl TestRoleInput
Sourcepub fn role(&self) -> Option<&str>
pub fn role(&self) -> Option<&str>
The IAM Amazon Resource Name (ARN) for the role that you want Elastic Transcoder to test.
Sourcepub fn input_bucket(&self) -> Option<&str>
pub fn input_bucket(&self) -> Option<&str>
The Amazon S3 bucket that contains media files to be transcoded. The action attempts to read from this bucket.
Sourcepub fn output_bucket(&self) -> Option<&str>
pub fn output_bucket(&self) -> Option<&str>
The Amazon S3 bucket that Elastic Transcoder writes transcoded media files to. The action attempts to read from this bucket.
Sourcepub fn topics(&self) -> &[String]
pub fn topics(&self) -> &[String]
The ARNs of one or more Amazon Simple Notification Service (Amazon SNS) topics that you want the action to send a test notification to.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .topics.is_none().
Sourceimpl TestRoleInput
impl TestRoleInput
Sourcepub fn builder() -> TestRoleInputBuilder
pub fn builder() -> TestRoleInputBuilder
Creates a new builder-style object to manufacture TestRoleInput.