Struct aws_sdk_elastictranscoder::output::ListJobsByStatusOutput [−][src]
#[non_exhaustive]pub struct ListJobsByStatusOutput {
pub jobs: Option<Vec<Job>>,
pub next_page_token: Option<String>,
}Expand description
The ListJobsByStatusResponse structure.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.jobs: Option<Vec<Job>>An array of Job objects that have the specified status.
next_page_token: Option<String> A value that you use to access the second and subsequent pages of results, if any. When
the jobs in the specified pipeline fit on one page or when you've reached the last page
of results, the value of NextPageToken is null.
Implementations
A value that you use to access the second and subsequent pages of results, if any. When
the jobs in the specified pipeline fit on one page or when you've reached the last page
of results, the value of NextPageToken is null.
Creates a new builder-style object to manufacture ListJobsByStatusOutput