Module aws_sdk_elastictranscoder::output [−][src]
Output structures for operations.
Modules
Structs
The response body contains a JSON object. If the job is successfully canceled, the value
The CreateJobResponse structure.
When you create a pipeline, Elastic Transcoder returns the values that you specified in the request.
The CreatePresetResponse structure.
The DeletePipelineResponse structure.
The DeletePresetResponse structure.
The ListJobsByPipelineResponse structure.
A list of the pipelines associated with the current AWS account.
The ListPresetsResponse structure.
The ReadJobResponse structure.
The ReadPipelineResponse structure.
The ReadPresetResponse structure.
The TestRoleResponse structure.
The UpdatePipelineNotificationsResponse structure.
When you update a pipeline, Elastic Transcoder returns the values that you specified in the request.
When you update status for a pipeline,